package cz.cvut.fel.pr2.du3.interfaces;

import cz.cvut.fel.pr2.du3.objects.DataObject;
import java.text.ParseException;

/**
 *
 * @author balikm1
 */
public interface IParser {
    /**
     * Parser used to transform string data into DataObject.
     * The format of the string needs to correspond to the following rules:
     *  - if the string starts with a digit, it is transformed into a NumberObject
     *  - if the string starts with a letter, it is transformed into a StringObject
     *  - if the string starts with a '{' character, a substring representing an element
     *      of an ArrayObject follows, matching any of the three rules. The substring
     *      needs to be terminated wit a '}' character.
     * Examples of valid string data:
     *      111
     *      a11
     *      {111}{a11}
     *      {{111}{a11}}{a11}
     * Examples of invalid string data:
     *      11a
     *      111 a11
     *      {111}a11
     *      {111{a11}}{a11}
     * 
     * @param data data to be parsed
     * @return object built from the data in case of successful parsing
     * @throws ParseException in case of invalid input data
     */
    DataObject parse(String data) throws ParseException;
}
